==> mule-module-zendesk-1.1-sources.jar: org/mule/modules/zendesk/jersey/SearchDeserializer.java <==
/**
 * (c) 2003-2012 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master
 * Subscription Agreement (or other Terms of Service) separately entered
 * into between you and MuleSoft. If such an agreement is not in
 * place, you may not use the software.
 */

package org.mule.modules.zendesk.jersey;

import com.google.gson.*;
import org.mule.modules.zendesk.model.Entity;
import org.mule.modules.zendesk.model.EntityType;
import org.mule.modules.zendesk.model.responses.SearchResponse;

import java.lang.reflect.Type;
import java.util.ArrayList;

/**
 * @author Mulesoft, Inc
 */
public class SearchDeserializer implements JsonDeserializer<SearchResponse> {

    @Override
    public SearchResponse deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context)
            throws JsonParseException {
        Gson gson = GsonFactory.getRawInstance();
        JsonArray results = json.getAsJsonObject().get("results").getAsJsonArray();

        Entity clazz;
        try {
            clazz = (Entity) EntityType.getClassOf(
                    results.get(0).getAsJsonObject().get("result_type").getAsString()).newInstance();
        } catch (InstantiationException e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        } catch (IllegalAccessException e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        }

        ArrayList searchResults = new ArrayList();
        SearchResponse response;

        try {
            for(JsonElement obj : results )
            {
                searchResults.add(gson.fromJson(obj, clazz.getClass()));
            }

            response = gson.fromJson(json, typeOfT);
            response.setResults(searchResults);
        }
        catch (Exception e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        }

        return response;
    }
}

==> mule-module-zendesk-2.0.2-sources.jar: org/mule/modules/zendesk/jersey/SearchDeserializer.java <==
/**
 * (c) 2003-2015 MuleSoft, Inc. The software in this package is
 * published under the terms of the CPAL v1.0 license, a copy of which
 * has been included with this distribution in the LICENSE.md file.
 */

package org.mule.modules.zendesk.jersey;

import com.google.gson.*;
import org.mule.modules.zendesk.model.Entity;
import org.mule.modules.zendesk.model.EntityType;
import org.mule.modules.zendesk.model.responses.SearchResponse;

import java.lang.reflect.Type;
import java.util.ArrayList;

/**
 * @author Mulesoft, Inc
 */
@SuppressWarnings("unchecked")
public class SearchDeserializer implements JsonDeserializer<SearchResponse> {

    public SearchResponse deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
        Gson gson = GsonFactory.getRawInstance();
        JsonArray results = json.getAsJsonObject().get("results").getAsJsonArray();
        SearchResponse response = new SearchResponse();

        Entity clazz;
        try {
            if (results != null && results.size() > 0) {
                clazz = (Entity) EntityType.getClassOf(results.get(0).getAsJsonObject().get("result_type").getAsString()).newInstance();
            } else {
                response.setResults(new ArrayList());
                return response;
            }
        } catch (InstantiationException e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        } catch (IllegalAccessException e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        }

        ArrayList searchResults = new ArrayList();

        try {
            for (JsonElement obj : results) {
                searchResults.add(gson.fromJson(obj, clazz.getClass()));
            }

            response = gson.fromJson(json, typeOfT);
            response.setResults(searchResults);
        } catch (Exception e) {
            throw new ZendeskException("Cannot deserialize search results. Please check the search operation documentation.");
        }

        return response;
    }
}
